@@ -17,6 +17,10 @@
 #' sample variances of the treatment and control sample, respectively. 
 #' Default \eqn{v_1=s_1^2}, \eqn{v_0=s_0^2}.
 #' 
+#' @param c1,c0 \link[base]{double} scalars or \link[base]{vector}s, 
+#' multipliers \eqn{c_1} and \eqn{c_0} of the treatment and control sample, respectively.
+#' Default \eqn{c_1=c_0=1}
+#' 
 #' @param n1,n0 \link[base]{integer} scalars or \link[base]{vector}s, 
 #' sample sizes \eqn{n_1} and \eqn{n_0} of the treatment and control sample, respectively
 #' 
@@ -62,10 +66,20 @@
 #' Gosset_Welch(v1 = vx, v0 = vy, n1 = nx, n0 = ny, var.equal = TRUE)
 #' @keywords internal
 #' @export
-Gosset_Welch <- function(s1, s0, v1 = s1^2, v0 = s0^2, n1, n0, var.equal = FALSE) {
+Gosset_Welch <- function(
+    s1, s0, 
+    c1 = 1, c0 = 1,
+    v1 = s1^2, v0 = s0^2, 
+    n1, n0, 
+    var.equal = FALSE
+) {
+  
   if (anyNA(v1) || anyNA(v0) || anyNA(n1) || anyNA(n0)) stop('do not allow missing')
   if (!is.logical(var.equal) || length(var.equal) != 1L || is.na(var.equal)) stop('`var.equal` must be len-1 logical')
   
+  v1 <- c1^2 * v1
+  v0 <- c0^2 * v0
+  
   if (var.equal) {
     vp <- ((n1-1L)*v1+(n0-1L)*v0) / (n1+n0-2L) # 'pooled variance'
     vd <- vp * (1/n1 + 1/n0) # variance of sample-mean *d*ifference
